@@ -184,6 +184,43 @@ class Runner(Session):
 
         resp.raise_for_status()
 
+    def get_dependencies(self, trace, job, dependencies=None):
+        """
+        Get the dependencies for the given job
+        :param trace: trace
+        :param job: gitlab job object
+        :param dependencies: optional list of earlier jobs to restrict to
+        :return:
+        """
+        pass
+
+    def upload(self, trace, job, archive_file):
+        """
+        Upload artifacts from a job
+        :param trace:
+        :param job:
+        :param archive_file:
+        :return:
+        """
+        url = self.api("jobs/{}/artifacts".format(job["id"]))
+        trace.writeline("Uploading artifacts to gitlab..")
+        with open(archive_file, "rb") as archive:
+            resp = self.post(url,
+                             params={
+                                 "artifact_format": "zip",
+                                 "artifact_type": "archive"
+                             },
+                             headers={
+                                 "Job-Token": job["token"]
+                             },
+                             files={
+                                 "file": (os.path.basename(archive_file),
+                                          archive,
+                                          "application/octet-stream")
+                             })
+        resp.raise_for_status()
+        trace.writeline("Upload complete")
+
 
 class DockerRunner(Runner):
     """
